pub struct UnstructuredGrid {
pub points: Points<f64>,
/* private fields */
}Expand description
Arbitrary mixed-cell mesh with explicit point coordinates and cell connectivity.
Analogous to VTK’s vtkUnstructuredGrid. Each cell has a type (from CellType)
and point connectivity stored in a shared CellArray. Cell types are stored in
a parallel array.
Fields
points: Points<f64>Implementations
Sourceimpl UnstructuredGrid
impl UnstructuredGrid
pub fn new() -> Self
Sourcepub fn push_cell(&mut self, cell_type: CellType, point_ids: &[i64])
pub fn push_cell(&mut self, cell_type: CellType, point_ids: &[i64])
Add a cell with the given type and point indices.
Sourcepub fn cell_points(&self, idx: usize) -> &[i64]
pub fn cell_points(&self, idx: usize) -> &[i64]
Get the point indices for cell at the given index.
Sourcepub fn cell_types(&self) -> &[CellType]
pub fn cell_types(&self) -> &[CellType]
Get all cell types.
pub fn point_data(&self) -> &DataSetAttributes
pub fn point_data_mut(&mut self) -> &mut DataSetAttributes
pub fn cell_data(&self) -> &DataSetAttributes
pub fn cell_data_mut(&mut self) -> &mut DataSetAttributes
Sourcepub fn from_tetrahedra(points: Vec<[f64; 3]>, tets: Vec<[i64; 4]>) -> Self
pub fn from_tetrahedra(points: Vec<[f64; 3]>, tets: Vec<[i64; 4]>) -> Self
Create from points and tetrahedra.
Sourcepub fn from_hexahedra(points: Vec<[f64; 3]>, hexes: Vec<[i64; 8]>) -> Self
pub fn from_hexahedra(points: Vec<[f64; 3]>, hexes: Vec<[i64; 8]>) -> Self
Create from points and hexahedra.
Sourcepub fn with_point_array(self, array: AnyDataArray) -> Self
pub fn with_point_array(self, array: AnyDataArray) -> Self
Builder: add a point data array.
Sourcepub fn with_cell_array(self, array: AnyDataArray) -> Self
pub fn with_cell_array(self, array: AnyDataArray) -> Self
Builder: add a cell data array.